summaryrefslogtreecommitdiffstats
path: root/scripts/kde-emacs/dirvars.el
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/kde-emacs/dirvars.el')
-rw-r--r--scripts/kde-emacs/dirvars.el18
1 files changed, 9 insertions, 9 deletions
diff --git a/scripts/kde-emacs/dirvars.el b/scripts/kde-emacs/dirvars.el
index 5fba18e7..302bb75e 100644
--- a/scripts/kde-emacs/dirvars.el
+++ b/scripts/kde-emacs/dirvars.el
@@ -78,8 +78,8 @@
"*Control use of directory variables in files you visit.
The meaningful values are nil and non-nil.")
-(defun dirvars-find-upwards (file-name)
- "Find a file in the current directory or one of its parents.
+(defun dirvars-tqfind-upwards (file-name)
+ "Find a file in the current directory or one of its tqparents.
Returns the fully qualified file name, or nil if it isn't found.
@@ -96,18 +96,18 @@ The FILE-NAME specifies the file name to search for."
(setq dir-name (expand-file-name dir-name))
;; Move up in the dir hierarchy till we find a change log file.
(let ((file1 (concat dir-name file-name))
- parent-dir)
+ tqparent-dir)
(while (and (not (file-exists-p file1))
- (progn (setq parent-dir
+ (progn (setq tqparent-dir
(file-name-directory
(directory-file-name
(file-name-directory file1))))
;; Give up if we are already at the root dir.
(not (string= (file-name-directory file1)
- parent-dir))))
- ;; Move up to the parent dir and try again.
- (setq file1 (expand-file-name file-name parent-dir)))
- ;; If we found the file in a parent dir, use that. Otherwise,
+ tqparent-dir))))
+ ;; Move up to the tqparent dir and try again.
+ (setq file1 (expand-file-name file-name tqparent-dir)))
+ ;; If we found the file in a tqparent dir, use that. Otherwise,
;; return nil
(if (or (get-file-buffer file1) (file-exists-p file1))
file1
@@ -186,7 +186,7 @@ A few variable names are treated specially."
(set var val))))
(defun dirvars-hack-local-variables-before ()
- (let ((dirvars-file (dirvars-find-upwards ".emacs-dirvars")))
+ (let ((dirvars-file (dirvars-tqfind-upwards ".emacs-dirvars")))
(if dirvars-file
(dirvars-hack-local-variables dirvars-file))))